@@ -93,6 +93,7 @@ int randshifting_tr_disq(int *,double *,double *,int,double *,double *,double,do
 	double *,double *,double *,double *,double *,double *,double);
 int randomlab(double *,double *,int,int *,int,double **,int *,double **);
 void randmark(int ,double *,double *);
+int randomdist(int *,int,double *,double *);
 
 int corr_rect(int *,double *,double *,double *, double *,double *,double *,double *,
 int *,double *,double *,double *);
@@ -135,20 +136,24 @@ int shimatani_tr_rect_ic(int *,double *,double *, double *,double *,double *,dou
 int shimatani_tr_disq_ic(int *,double *,double *, double *,double *,double *,int *, double *, double *, double *, double *, double *, double *,
 						 int *,double *,int *,double *,int *,int *,double *,double *,double *, double *,double *,double *,double *,double *,double *,double *,int *);
 
-int rao_rect(int *,double *,double *,double *,double *,double *,double *,int *,double *,double *,double *, int*, double *,int *);
-int rao_disq(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *, int *,double *,int *);
+int rao_rect(int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,int *,int *,double *,double *,double *,double *,
+			 double *,double *,double *,int *);
+int rao_rect_ic(int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,int *,double *,int *,int *,double *,double *,
+				double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,int *);
+int rao_disq(int *,double *,double *,double *,double *,double *,int *,double *,int *,int *,int *,double *,double *,double *,double *,
+			 double *,double *,double *,int *);
+int rao_disq_ic(int *,double *,double *,double *,double *,double *,int *,double *,int *,int *,double *,int *,int *,double *,double *,
+				double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,int *);
 int rao_tr_rect(int *,double *,double *,double *,double *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
-				int *,double *,double *,double *,int *,double *,int *);
-int rao_tr_disq(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
-				int *,double *,double *,double *,int *,double *,int *);
-int rao_rect_ic(int *,double *,double *,double *,double *,double *,double *,double *,int *,double *,int *,double *,double *,double *,double *,
-				double *,double *, double *,double *,double *,double *,int *,int *,double *);
-int rao_disq_ic(int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,double *,double *,double *,double *,
-				double *,double *, double *,double *, double *, double *,int *,int *, double *);
-int rao_tr_rect_ic(int *,double *,double *,double *,double *,double *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
-				   int *,double *,int *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,int *,int *,double *);
-int rao_tr_disq_ic(int *,double *,double *,double *,double *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
-				   int *,double *,int *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,int *,int *,double *);
+				int *,double *,int *,int *,int *,double *,double *,double *,double *,double *,double *,double *,int *);
+
+int rao_tr_rect_ic(int *,double *,double *,double *,double *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
+				   int *,double *,int *,int *,double *,int *,int *,double *,double *,double *,double *,double *,double *,double *,double *,
+				   double *,double *,double *,double *,double *,int *);
+int rao_tr_disq(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,int *,int *,
+				double *,double *,double *,double *,double *,double *,double *,int *);
+int rao_tr_disq_ic(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,int *,double *,
+				   int *,int *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,int *);
 
 int mimetic_rect(int *,double *,double *, double *,double *,double *,double *,double *,double *, int *,double *,double *,int *,int *,double *,double *,double *,double *,double *);
 int mimetic_disq(int *,double *,double *,double *,double *,double *,double *,double *, int *, double *, double *, int *, int *, double *,double *,double *,double *,double *);
